@@ -23,7 +23,7 @@ namespace Tellico {
  * A collection for games.
  */
 class GameCollection : public Collection {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
