@@ -50,23 +50,23 @@ DetailedListView::DetailedListView(TQWidget* parent_, const char* name_/*=0*/)
   setShowSortIndicator(true);
   setShadeSortColumn(true);
 
-//  connect(this, TQT_SIGNAL(selectionChanged()), TQT_SLOT(slotSelectionChanged()));
-  connect(this, TQT_SIGNAL(contextMenuRequested(TQListViewItem*, const TQPoint&, int)),
-          TQT_SLOT(contextMenuRequested(TQListViewItem*, const TQPoint&, int)));
-  connect(header(), TQT_SIGNAL(indexChange(int, int, int)),
-          TQT_SLOT(slotUpdatePixmap()));
+//  connect(this, TQ_SIGNAL(selectionChanged()), TQ_SLOT(slotSelectionChanged()));
+  connect(this, TQ_SIGNAL(contextMenuRequested(TQListViewItem*, const TQPoint&, int)),
+          TQ_SLOT(contextMenuRequested(TQListViewItem*, const TQPoint&, int)));
+  connect(header(), TQ_SIGNAL(indexChange(int, int, int)),
+          TQ_SLOT(slotUpdatePixmap()));
 
   // header menu
   header()->setClickEnabled(true);
   header()->installEventFilter(this);
-  connect(header(), TQT_SIGNAL(sizeChange(int, int, int)),
-          this, TQT_SLOT(slotCacheColumnWidth(int, int, int)));
+  connect(header(), TQ_SIGNAL(sizeChange(int, int, int)),
+          this, TQ_SLOT(slotCacheColumnWidth(int, int, int)));
 
   m_headerMenu = new TDEPopupMenu(this);
   m_headerMenu->setCheckable(true);
   m_headerMenu->insertTitle(i18n("View Columns"));
-  connect(m_headerMenu, TQT_SIGNAL(activated(int)),
-          this, TQT_SLOT(slotHeaderMenuActivated(int)));
+  connect(m_headerMenu, TQ_SIGNAL(activated(int)),
+          this, TQ_SLOT(slotHeaderMenuActivated(int)));
 
   m_checkPix = UserIcon(TQString::fromLatin1("checkmark"));
 }
@@ -377,9 +377,9 @@ Tellico::DetailedEntryItem* DetailedListView::locateItem(Data::EntryPtr entry_)
 
 bool DetailedListView::eventFilter(TQObject* obj_, TQEvent* ev_) {
   if(ev_->type() == TQEvent::MouseButtonPress
-      && TQT_TQMOUSEEVENT(ev_)->button() == Qt::RightButton
-      && TQT_BASE_OBJECT(obj_) == TQT_BASE_OBJECT(header())) {
-    m_headerMenu->popup(TQT_TQMOUSEEVENT(ev_)->globalPos());
+      && static_cast<TQMouseEvent*>(ev_)->button() == TQt::RightButton
+      && obj_ == header()) {
+    m_headerMenu->popup(static_cast<TQMouseEvent*>(ev_)->globalPos());
     return true;
   }
   return GUI::ListView::eventFilter(obj_, ev_);
