@@ -42,10 +42,10 @@ EntryUpdater::EntryUpdater(Data::CollPtr coll_, Data::EntryVec entries_, TQObjec
   // for now, we're assuming all entries are same collection type
   m_fetchers = Fetch::Manager::self()->createUpdateFetchers(m_coll->type());
   for(Fetch::FetcherVec::Iterator it = m_fetchers.begin(); it != m_fetchers.end(); ++it) {
-    connect(it.data(), TQT_SIGNAL(signalResultFound(Tellico::Fetch::SearchResult*)),
-            TQT_SLOT(slotResult(Tellico::Fetch::SearchResult*)));
-    connect(it.data(), TQT_SIGNAL(signalDone(Tellico::Fetch::Fetcher::Ptr)),
-            TQT_SLOT(slotDone()));
+    connect(it.data(), TQ_SIGNAL(signalResultFound(Tellico::Fetch::SearchResult*)),
+            TQ_SLOT(slotResult(Tellico::Fetch::SearchResult*)));
+    connect(it.data(), TQ_SIGNAL(signalDone(Tellico::Fetch::Fetcher::Ptr)),
+            TQ_SLOT(slotDone()));
   }
   init();
 }
@@ -59,10 +59,10 @@ EntryUpdater::EntryUpdater(const TQString& source_, Data::CollPtr coll_, Data::E
   Fetch::Fetcher::Ptr f = Fetch::Manager::self()->createUpdateFetcher(m_coll->type(), source_);
   if(f) {
     m_fetchers.append(f);
-    connect(f, TQT_SIGNAL(signalResultFound(Tellico::Fetch::SearchResult*)),
-            TQT_SLOT(slotResult(Tellico::Fetch::SearchResult*)));
-    connect(f, TQT_SIGNAL(signalDone(Tellico::Fetch::Fetcher::Ptr)),
-            TQT_SLOT(slotDone()));
+    connect(f, TQ_SIGNAL(signalResultFound(Tellico::Fetch::SearchResult*)),
+            TQ_SLOT(slotResult(Tellico::Fetch::SearchResult*)));
+    connect(f, TQ_SIGNAL(signalDone(Tellico::Fetch::Fetcher::Ptr)),
+            TQ_SLOT(slotDone()));
   }
   init();
 }
@@ -85,11 +85,11 @@ void EntryUpdater::init() {
   Kernel::self()->beginCommandGroup(i18n("Update Entries"));
   ProgressItem& item = ProgressManager::self()->newProgressItem(this, label, true /*canCancel*/);
   item.setTotalSteps(m_fetchers.count() * m_origEntryCount);
-  connect(&item, TQT_SIGNAL(signalCancelled(ProgressItem*)), TQT_SLOT(slotCancel()));
+  connect(&item, TQ_SIGNAL(signalCancelled(ProgressItem*)), TQ_SLOT(slotCancel()));
 
   // done if no fetchers available
   if(m_fetchers.isEmpty()) {
-    TQTimer::singleShot(500, this, TQT_SLOT(slotCleanup()));
+    TQTimer::singleShot(500, this, TQ_SLOT(slotCleanup()));
   } else {
     slotStartNext(); // starts fetching
   }
@@ -107,7 +107,7 @@ void EntryUpdater::slotStartNext() {
 void EntryUpdater::slotDone() {
   if(m_cancelled) {
     myLog() << "EntryUpdater::slotDone() - cancelled" << endl;
-    TQTimer::singleShot(500, this, TQT_SLOT(slotCleanup()));
+    TQTimer::singleShot(500, this, TQ_SLOT(slotCleanup()));
     return;
   }
 
@@ -125,13 +125,13 @@ void EntryUpdater::slotDone() {
     m_entriesToUpdate.remove(m_entriesToUpdate.begin());
     // if there are no more entries, and this is the last fetcher, time to delete
     if(m_entriesToUpdate.isEmpty()) {
-      TQTimer::singleShot(500, this, TQT_SLOT(slotCleanup()));
+      TQTimer::singleShot(500, this, TQ_SLOT(slotCleanup()));
       return;
     }
   }
   kapp->processEvents();
   // so the entry updater can clean up a bit
-  TQTimer::singleShot(500, this, TQT_SLOT(slotStartNext()));
+  TQTimer::singleShot(500, this, TQ_SLOT(slotStartNext()));
 }
 
 void EntryUpdater::slotResult(Fetch::SearchResult* result_) {
