@@ -32,7 +32,7 @@ namespace Tellico {
  * @author Robby Stephenson
  */
 class ExportDialog : public KDialogBase {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
