@@ -47,7 +47,7 @@ namespace Tellico {
  * @author Robby Stephenson
  */
 class AmazonFetcher : public Fetcher {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
@@ -138,7 +138,7 @@ private:
 };
 
 class AmazonFetcher::ConfigWidget : public Fetch::ConfigWidget {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
