@@ -104,10 +104,10 @@ void CrossRefFetcher::search(FetchKey key_, const TQString& value_) {
   }
 
   m_job = TDEIO::get(u, false, false);
-  connect(m_job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
-          TQT_SLOT(slotData(TDEIO::Job*, const TQByteArray&)));
-  connect(m_job, TQT_SIGNAL(result(TDEIO::Job*)),
-          TQT_SLOT(slotComplete(TDEIO::Job*)));
+  connect(m_job, TQ_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+          TQ_SLOT(slotData(TDEIO::Job*, const TQByteArray&)));
+  connect(m_job, TQ_SIGNAL(result(TDEIO::Job*)),
+          TQ_SLOT(slotComplete(TDEIO::Job*)));
 }
 
 void CrossRefFetcher::stop() {
@@ -352,7 +352,7 @@ CrossRefFetcher::ConfigWidget::ConfigWidget(TQWidget* parent_, const CrossRefFet
   TQLabel* label = new TQLabel(i18n("&Username: "), optionsWidget());
   l->addWidget(label, ++row, 0);
   m_userEdit = new KLineEdit(optionsWidget());
-  connect(m_userEdit, TQT_SIGNAL(textChanged(const TQString&)), TQT_SLOT(slotSetModified()));
+  connect(m_userEdit, TQ_SIGNAL(textChanged(const TQString&)), TQ_SLOT(slotSetModified()));
   l->addWidget(m_userEdit, row, 1);
   TQString w = i18n("A username and password is required to access the CrossRef service. The password is "
                    "stored as plain text in the Tellico configuration file.");
@@ -363,7 +363,7 @@ CrossRefFetcher::ConfigWidget::ConfigWidget(TQWidget* parent_, const CrossRefFet
   label = new TQLabel(i18n("&Password: "), optionsWidget());
   l->addWidget(label, ++row, 0);
   m_passEdit = new KLineEdit(optionsWidget());
-  connect(m_passEdit, TQT_SIGNAL(textChanged(const TQString&)), TQT_SLOT(slotSetModified()));
+  connect(m_passEdit, TQ_SIGNAL(textChanged(const TQString&)), TQ_SLOT(slotSetModified()));
   l->addWidget(m_passEdit, row, 1);
   TQWhatsThis::add(label, w);
   TQWhatsThis::add(m_passEdit, w);
