@@ -120,10 +120,10 @@ void YahooFetcher::doSearch() {
 //  myDebug() << "YahooFetcher::search() - url: " << u.url() << endl;
 
   m_job = TDEIO::get(u, false, false);
-  connect(m_job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
-          TQT_SLOT(slotData(TDEIO::Job*, const TQByteArray&)));
-  connect(m_job, TQT_SIGNAL(result(TDEIO::Job*)),
-          TQT_SLOT(slotComplete(TDEIO::Job*)));
+  connect(m_job, TQ_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+          TQ_SLOT(slotData(TDEIO::Job*, const TQByteArray&)));
+  connect(m_job, TQ_SIGNAL(result(TDEIO::Job*)),
+          TQ_SLOT(slotComplete(TDEIO::Job*)));
 }
 
 void YahooFetcher::stop() {
