@@ -107,13 +107,13 @@ FetchDialog::FetchDialog(TQWidget* parent_, const char* name_)
   for(Fetch::KeyMap::ConstIterator it = map.begin(); it != map.end(); ++it) {
     m_keyCombo->insertItem(it.data(), it.key());
   }
-  connect(m_keyCombo, TQT_SIGNAL(activated(int)), TQT_SLOT(slotKeyChanged(int)));
+  connect(m_keyCombo, TQ_SIGNAL(activated(int)), TQ_SLOT(slotKeyChanged(int)));
   TQWhatsThis::add(m_keyCombo, i18n("Choose the type of search"));
 
   m_searchButton = new KPushButton(box1);
   m_searchButton->setGuiItem(KGuiItem(i18n(FETCH_STRING_STOP),
                                       SmallIconSet(TQString::fromLatin1("cancel"))));
-  connect(m_searchButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotSearchClicked()));
+  connect(m_searchButton, TQ_SIGNAL(clicked()), TQ_SLOT(slotSearchClicked()));
   TQWhatsThis::add(m_searchButton, i18n("Click to start or stop the search"));
 
   // the search button's text changes from search to stop
@@ -133,12 +133,12 @@ FetchDialog::FetchDialog(TQWidget* parent_, const char* name_)
 
   m_multipleISBN = new TQCheckBox(i18n("&Multiple ISBN/UPC search"), box2);
   TQWhatsThis::add(m_multipleISBN, i18n("Check this box to search for multiple ISBN or UPC values."));
-  connect(m_multipleISBN, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotMultipleISBN(bool)));
+  connect(m_multipleISBN, TQ_SIGNAL(toggled(bool)), TQ_SLOT(slotMultipleISBN(bool)));
 
   m_editISBN = new KPushButton(KGuiItem(i18n("Edit List..."), TQString::fromLatin1("text_block")), box2);
   m_editISBN->setEnabled(false);
   TQWhatsThis::add(m_editISBN, i18n("Click to open a text edit box for entering or editing multiple ISBN values."));
-  connect(m_editISBN, TQT_SIGNAL(clicked()), TQT_SLOT(slotEditMultipleISBN()));
+  connect(m_editISBN, TQ_SIGNAL(clicked()), TQ_SLOT(slotEditMultipleISBN()));
 
   // add for spacing
   box2->setStretchFactor(new TQWidget(box2), 10);
@@ -150,10 +150,10 @@ FetchDialog::FetchDialog(TQWidget* parent_, const char* name_)
   for(Fetch::FetcherVec::Iterator it = sources.begin(); it != sources.end(); ++it) {
     m_sourceCombo->insertItem(Fetch::Manager::self()->fetcherIcon(it.data()), (*it).source());
   }
-  connect(m_sourceCombo, TQT_SIGNAL(activated(const TQString&)), TQT_SLOT(slotSourceChanged(const TQString&)));
+  connect(m_sourceCombo, TQ_SIGNAL(activated(const TQString&)), TQ_SLOT(slotSourceChanged(const TQString&)));
   TQWhatsThis::add(m_sourceCombo, i18n("Select the database to search"));
 
-  TQSplitter* split = new TQSplitter(Qt::Vertical, mainWidget);
+  TQSplitter* split = new TQSplitter(TQt::Vertical, mainWidget);
   topLayout->addWidget(split);
 
   m_listView = new GUI::ListView(split);
@@ -171,9 +171,9 @@ FetchDialog::FetchDialog(TQWidget* parent_, const char* name_)
   m_listView->addColumn(i18n("Source"));
   m_listView->viewport()->installEventFilter(this);
 
-  connect(m_listView, TQT_SIGNAL(selectionChanged()), TQT_SLOT(slotShowEntry()));
+  connect(m_listView, TQ_SIGNAL(selectionChanged()), TQ_SLOT(slotShowEntry()));
   // double clicking should add the entry
-  connect(m_listView, TQT_SIGNAL(doubleClicked(TQListViewItem*)), TQT_SLOT(slotAddEntry()));
+  connect(m_listView, TQ_SIGNAL(doubleClicked(TQListViewItem*)), TQ_SLOT(slotAddEntry()));
   TQWhatsThis::add(m_listView, i18n("As results are found, they are added to this list. Selecting one "
                                    "will fetch the complete entry and show it in the view below."));
 
@@ -192,16 +192,16 @@ FetchDialog::FetchDialog(TQWidget* parent_, const char* name_)
   m_addButton = new KPushButton(i18n("&Add Entry"), box3);
   m_addButton->setEnabled(false);
   m_addButton->setIconSet(UserIconSet(Kernel::self()->collectionTypeName()));
-  connect(m_addButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotAddEntry()));
+  connect(m_addButton, TQ_SIGNAL(clicked()), TQ_SLOT(slotAddEntry()));
   TQWhatsThis::add(m_addButton, i18n("Add the selected entry to the current collection"));
 
   m_moreButton = new KPushButton(KGuiItem(i18n("Get More Results"), SmallIconSet(TQString::fromLatin1("edit-find"))), box3);
   m_moreButton->setEnabled(false);
-  connect(m_moreButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotMoreClicked()));
+  connect(m_moreButton, TQ_SIGNAL(clicked()), TQ_SLOT(slotMoreClicked()));
   TQWhatsThis::add(m_moreButton, i18n("Fetch more results from the current data source"));
 
   KPushButton* clearButton = new KPushButton(KStdGuiItem::clear(), box3);
-  connect(clearButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotClearClicked()));
+  connect(clearButton, TQ_SIGNAL(clicked()), TQ_SLOT(slotClearClicked()));
   TQWhatsThis::add(clearButton, i18n("Clear all search fields and results"));
 
   TQHBox* bottombox = new TQHBox(mainWidget, "box");
@@ -218,9 +218,9 @@ FetchDialog::FetchDialog(TQWidget* parent_, const char* name_)
   m_statusBar->addWidget(m_progress, 0, true);
 
   KPushButton* closeButton = new KPushButton(KStdGuiItem::close(), bottombox);
-  connect(closeButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotClose()));
+  connect(closeButton, TQ_SIGNAL(clicked()), TQ_SLOT(slotClose()));
 
-  connect(m_timer, TQT_SIGNAL(timeout()), TQT_SLOT(slotMoveProgress()));
+  connect(m_timer, TQ_SIGNAL(timeout()), TQ_SLOT(slotMoveProgress()));
 
   setMinimumWidth(TQMAX(minimumWidth(), FETCH_MIN_WIDTH));
   setStatus(i18n("Ready."));
@@ -233,19 +233,19 @@ FetchDialog::FetchDialog(TQWidget* parent_, const char* name_)
     split->setSizes(splitList);
   }
 
-  connect(Fetch::Manager::self(), TQT_SIGNAL(signalResultFound(Tellico::Fetch::SearchResult*)),
-                                  TQT_SLOT(slotResultFound(Tellico::Fetch::SearchResult*)));
-  connect(Fetch::Manager::self(), TQT_SIGNAL(signalStatus(const TQString&)),
-                                  TQT_SLOT(slotStatus(const TQString&)));
-  connect(Fetch::Manager::self(), TQT_SIGNAL(signalDone()),
-                                  TQT_SLOT(slotFetchDone()));
+  connect(Fetch::Manager::self(), TQ_SIGNAL(signalResultFound(Tellico::Fetch::SearchResult*)),
+                                  TQ_SLOT(slotResultFound(Tellico::Fetch::SearchResult*)));
+  connect(Fetch::Manager::self(), TQ_SIGNAL(signalStatus(const TQString&)),
+                                  TQ_SLOT(slotStatus(const TQString&)));
+  connect(Fetch::Manager::self(), TQ_SIGNAL(signalDone()),
+                                  TQ_SLOT(slotFetchDone()));
 
   // make sure to delete results afterwards
   m_results.setAutoDelete(true);
 
   TDEAcceleratorManager::manage(this);
   // initialize combos
-  TQTimer::singleShot(0, this, TQT_SLOT(slotInit()));
+  TQTimer::singleShot(0, this, TQ_SLOT(slotInit()));
 
 #ifdef ENABLE_WEBCAM
   // barcode recognition
@@ -258,8 +258,8 @@ FetchDialog::FetchDialog(TQWidget* parent_, const char* name_)
   } else {
     m_barcodePreview = 0;
   }
-  connect( m_barcodeRecognitionThread, TQT_SIGNAL(recognized(TQString)), this, TQT_SLOT(slotBarcodeRecognized(TQString)) );
-  connect( m_barcodeRecognitionThread, TQT_SIGNAL(gotImage(TQImage&)), this, TQT_SLOT(slotBarcodeGotImage(TQImage&)) );
+  connect( m_barcodeRecognitionThread, TQ_SIGNAL(recognized(TQString)), this, TQ_SLOT(slotBarcodeRecognized(TQString)) );
+  connect( m_barcodeRecognitionThread, TQ_SIGNAL(gotImage(TQImage&)), this, TQ_SLOT(slotBarcodeGotImage(TQImage&)) );
   m_barcodeRecognitionThread->start();
 /*  //DEBUG
   TQImage img( "/home/sebastian/white.png", "PNG" );
@@ -339,7 +339,7 @@ void FetchDialog::slotStatus(const TQString& status_) {
   // if the queue was empty, start the timer
   if(m_statusMessages.count() == 1) {
     // wait 2 seconds
-    TQTimer::singleShot(2000, this, TQT_SLOT(slotUpdateStatus()));
+    TQTimer::singleShot(2000, this, TQ_SLOT(slotUpdateStatus()));
   }
 }
 
@@ -351,7 +351,7 @@ void FetchDialog::slotUpdateStatus() {
   m_statusMessages.pop_front();
   if(!m_statusMessages.isEmpty()) {
     // wait 2 seconds
-    TQTimer::singleShot(2000, this, TQT_SLOT(slotUpdateStatus()));
+    TQTimer::singleShot(2000, this, TQ_SLOT(slotUpdateStatus()));
   }
 }
 
@@ -417,7 +417,7 @@ void FetchDialog::slotFetchDone(bool checkISBN /* = true */) {
       lay->addWidget(edit);
       edit->setText(values.join(TQChar('\n')));
       TQWhatsThis::add(edit, s);
-      connect(dlg, TQT_SIGNAL(okClicked()), dlg, TQT_SLOT(deleteLater()));
+      connect(dlg, TQ_SIGNAL(okClicked()), dlg, TQ_SLOT(deleteLater()));
       dlg->setMainWidget(box);
       dlg->setMinimumWidth(TQMAX(dlg->minimumWidth(), FETCH_MIN_WIDTH*2/3));
       dlg->show();
@@ -553,10 +553,10 @@ void FetchDialog::slotKeyChanged(int idx_) {
   if(key == Fetch::ISBN || key == Fetch::UPC || key == Fetch::LCCN) {
     m_multipleISBN->setEnabled(true);
     if(key == Fetch::ISBN) {
-      m_valueLineEdit->setValidator(new ISBNValidator(TQT_TQOBJECT(this)));
+      m_valueLineEdit->setValidator(new ISBNValidator(this));
     } else {
-      UPCValidator* upc = new UPCValidator(TQT_TQOBJECT(this));
-      connect(upc, TQT_SIGNAL(signalISBN()), TQT_SLOT(slotUPC2ISBN()));
+      UPCValidator* upc = new UPCValidator(this);
+      connect(upc, TQ_SIGNAL(signalISBN()), TQ_SLOT(slotUPC2ISBN()));
       m_valueLineEdit->setValidator(upc);
       // only want to convert to ISBN if ISBN is accepted by the fetcher
       Fetch::KeyMap map = Fetch::Manager::self()->keyMap(m_sourceCombo->currentText());
@@ -610,7 +610,7 @@ void FetchDialog::slotEditMultipleISBN() {
   KPushButton* fromFileBtn = new KPushButton(SmallIconSet(TQString::fromLatin1("document-open")),
                                              i18n("&Load From File..."), box);
   TQWhatsThis::add(fromFileBtn, i18n("<qt>Load the list from a text file.</qt>"));
-  connect(fromFileBtn, TQT_SIGNAL(clicked()), TQT_SLOT(slotLoadISBNList()));
+  connect(fromFileBtn, TQ_SIGNAL(clicked()), TQ_SLOT(slotLoadISBNList()));
   dlg.setMainWidget(box);
   dlg.setMinimumWidth(TQMAX(dlg.minimumWidth(), FETCH_MIN_WIDTH*2/3));
 
