@@ -30,7 +30,7 @@ namespace Tellico {
  * @author Robby Stephenson
  */
 class URLFieldWidget : public FieldWidget {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
