@@ -189,7 +189,7 @@ Tellico::Data::CollPtr CSVImporter::collection() {
 
   ProgressItem& item = ProgressManager::self()->newProgressItem(this, progressLabel(), true);
   item.setTotalSteps(numLines);
-  connect(&item, TQT_SIGNAL(signalCancelled(ProgressItem*)), TQT_SLOT(slotCancel()));
+  connect(&item, TQ_SIGNAL(signalCancelled(ProgressItem*)), TQ_SLOT(slotCancel()));
   ProgressItem::Done done(this);
 
   uint j = 0;
@@ -237,14 +237,14 @@ Tellico::Data::CollPtr CSVImporter::collection() {
 }
 
 TQWidget* CSVImporter::widget(TQWidget* parent_, const char* name_) {
-  if(m_widget && TQT_BASE_OBJECT(m_widget->parent()) == TQT_BASE_OBJECT(parent_)) {
+  if(m_widget && m_widget->parent() == parent_) {
     return m_widget;
   }
 
   m_widget = new TQWidget(parent_, name_);
   TQVBoxLayout* l = new TQVBoxLayout(m_widget);
 
-  TQGroupBox* group = new TQGroupBox(1, Qt::Horizontal, i18n("CSV Options"), m_widget);
+  TQGroupBox* group = new TQGroupBox(1, TQt::Horizontal, i18n("CSV Options"), m_widget);
   l->addWidget(group);
 
   TQHBox* box = new TQHBox(group);
@@ -253,22 +253,22 @@ TQWidget* CSVImporter::widget(TQWidget* parent_, const char* name_) {
   m_comboColl = new GUI::CollectionTypeCombo(box);
   lab->setBuddy(m_comboColl);
   TQWhatsThis::add(m_comboColl, i18n("Select the type of collection being imported."));
-  connect(m_comboColl, TQT_SIGNAL(activated(int)), TQT_SLOT(slotTypeChanged()));
+  connect(m_comboColl, TQ_SIGNAL(activated(int)), TQ_SLOT(slotTypeChanged()));
   // need a spacer
   TQWidget* w = new TQWidget(box);
   box->setStretchFactor(w, 1);
 
   m_checkFirstRowHeader = new TQCheckBox(i18n("&First row contains field titles"), group);
   TQWhatsThis::add(m_checkFirstRowHeader, i18n("If checked, the first row is used as field titles."));
-  connect(m_checkFirstRowHeader, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotFirstRowHeader(bool)));
+  connect(m_checkFirstRowHeader, TQ_SIGNAL(toggled(bool)), TQ_SLOT(slotFirstRowHeader(bool)));
 
   TQHBox* hbox2 = new TQHBox(group);
-  m_delimiterGroup = new TQButtonGroup(0, Qt::Vertical, i18n("Delimiter"), hbox2);
+  m_delimiterGroup = new TQButtonGroup(0, TQt::Vertical, i18n("Delimiter"), hbox2);
   TQGridLayout* m_delimiterGroupLayout = new TQGridLayout(m_delimiterGroup->layout(), 3, 3);
   m_delimiterGroupLayout->setAlignment(TQt::AlignTop);
   TQWhatsThis::add(m_delimiterGroup, i18n("In addition to a comma, other characters may be used as "
                                          "a delimiter, separating each value in the file."));
-  connect(m_delimiterGroup, TQT_SIGNAL(clicked(int)), TQT_SLOT(slotDelimiter()));
+  connect(m_delimiterGroup, TQ_SIGNAL(clicked(int)), TQ_SLOT(slotDelimiter()));
 
   m_radioComma = new TQRadioButton(m_delimiterGroup);
   m_radioComma->setText(i18n("&Comma"));
@@ -297,9 +297,9 @@ TQWidget* CSVImporter::widget(TQWidget* parent_, const char* name_) {
   m_editOther->setMaxLength(1);
   TQWhatsThis::add(m_editOther, i18n("A custom string, such as a colon, may be used as a delimiter."));
   m_delimiterGroupLayout->addWidget(m_editOther, 2, 2);
-  connect(m_radioOther, TQT_SIGNAL(toggled(bool)),
-          m_editOther, TQT_SLOT(setEnabled(bool)));
-  connect(m_editOther, TQT_SIGNAL(textChanged(const TQString&)), TQT_SLOT(slotDelimiter()));
+  connect(m_radioOther, TQ_SIGNAL(toggled(bool)),
+          m_editOther, TQ_SLOT(setEnabled(bool)));
+  connect(m_editOther, TQ_SIGNAL(textChanged(const TQString&)), TQ_SLOT(slotDelimiter()));
 
   w = new TQWidget(hbox2);
   hbox2->setStretchFactor(w, 1);
@@ -313,8 +313,8 @@ TQWidget* CSVImporter::widget(TQWidget* parent_, const char* name_) {
   m_table->setReadOnly(true);
   m_table->setMinimumHeight(m_widget->fontMetrics().lineSpacing() * 8);
   TQWhatsThis::add(m_table, i18n("The table shows up to the first five lines of the CSV file."));
-  connect(m_table, TQT_SIGNAL(currentChanged(int, int)), TQT_SLOT(slotCurrentChanged(int, int)));
-  connect(m_table->horizontalHeader(), TQT_SIGNAL(clicked(int)), TQT_SLOT(slotHeaderClicked(int)));
+  connect(m_table, TQ_SIGNAL(currentChanged(int, int)), TQ_SLOT(slotCurrentChanged(int, int)));
+  connect(m_table->horizontalHeader(), TQ_SIGNAL(clicked(int)), TQ_SLOT(slotHeaderClicked(int)));
 
   TQWidget* hbox = new TQWidget(group);
   TQHBoxLayout* hlay = new TQHBoxLayout(hbox, 5);
@@ -326,7 +326,7 @@ TQWidget* CSVImporter::widget(TQWidget* parent_, const char* name_) {
   m_colSpinBox = new KIntSpinBox(hbox);
   hlay->addWidget(m_colSpinBox);
   m_colSpinBox->setMinValue(1);
-  connect(m_colSpinBox, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(slotSelectColumn(int)));
+  connect(m_colSpinBox, TQ_SIGNAL(valueChanged(int)), TQ_SLOT(slotSelectColumn(int)));
   lab->setBuddy(m_colSpinBox);
   hlay->addSpacing(10);
 
@@ -334,14 +334,14 @@ TQWidget* CSVImporter::widget(TQWidget* parent_, const char* name_) {
   hlay->addWidget(lab);
   m_comboField = new KComboBox(hbox);
   hlay->addWidget(m_comboField);
-  connect(m_comboField, TQT_SIGNAL(activated(int)), TQT_SLOT(slotFieldChanged(int)));
+  connect(m_comboField, TQ_SIGNAL(activated(int)), TQ_SLOT(slotFieldChanged(int)));
   lab->setBuddy(m_comboField);
   hlay->addSpacing(10);
 
   m_setColumnBtn = new KPushButton(i18n("&Assign Field"), hbox);
   hlay->addWidget(m_setColumnBtn);
   m_setColumnBtn->setIconSet(SmallIconSet(TQString::fromLatin1("apply")));
-  connect(m_setColumnBtn, TQT_SIGNAL(clicked()), TQT_SLOT(slotSetColumnTitle()));
+  connect(m_setColumnBtn, TQ_SIGNAL(clicked()), TQ_SLOT(slotSetColumnTitle()));
   hlay->addStretch(10);
 
   l->addStretch(1);
