@@ -34,7 +34,7 @@ namespace Tellico {
  * @author Robby Stephenson
  */
 class FileListingImporter : public Importer {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
