@@ -27,7 +27,7 @@ namespace Tellico {
  * @author Robby Stephenson
  */
 class PilotDBExporter : public Exporter {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
